summary refs log tree commit diff
path: root/pkgs/development/ocaml-modules/ocaml-cairo2
diff options
context:
space:
mode:
Diffstat (limited to 'pkgs/development/ocaml-modules/ocaml-cairo2')
-rw-r--r--pkgs/development/ocaml-modules/ocaml-cairo2/default.nix6
1 files changed, 3 insertions, 3 deletions
diff --git a/pkgs/development/ocaml-modules/ocaml-cairo2/default.nix b/pkgs/development/ocaml-modules/ocaml-cairo2/default.nix
index 6b9f6f09ea32..204adeb9451e 100644
--- a/pkgs/development/ocaml-modules/ocaml-cairo2/default.nix
+++ b/pkgs/development/ocaml-modules/ocaml-cairo2/default.nix
@@ -1,7 +1,7 @@
-{ stdenv, fetchurl, ocaml, findlib, pkgconfig, cairo, lablgtk, gtk,
+{ stdenv, fetchurl, ocaml, findlib, pkgconfig, cairo, lablgtk, gtk2,
   enableGtkSupport ? true # Whether to compile with support for Gtk
                           # integration (library file cairo2_gtk). Depends
                           # on lablgtk and gtk.
 }:
 
 let
@@ -20,7 +20,7 @@ stdenv.mkDerivation {
   };
 
   buildInputs = [ ocaml findlib pkgconfig cairo ]
-                ++ optionals enableGtkSupport [ gtk ];
+                ++ optionals enableGtkSupport [ gtk2 ];
 
   # lablgtk2 is marked as a propagated build input since loading the
   # cairo.lablgtk2 package from the toplevel tries to load lablgtk2 as
@@ -1,7 +1,7 @@
   enableGtkSupport ? true # Whether to compile with support for Gtk
                           # integration (library file cairo2_gtk). Depends
-                          # on lablgtk and gtk.
+                          # on lablgtk and gtk2.
 }:
 